<?php defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'OVABRW_WCFM_Ajaxs' ) ) {

	class OVABRW_WCFM_Ajaxs {

		public function __construct() {
			$ajaxs = array(
				'get_custom_tax_in_cat',
				'get_order_list',
				'filter_order',
				'update_order_status'
			);

			foreach ( $ajaxs as $ajax_name ) {
				add_action( 'wp_ajax_ovabrw_wcfm_'.$ajax_name, array( $this, 'ovabrw_wcfm_'.$ajax_name ) );
				add_action( 'wp_ajax_nopriv_ovabrw_wcfm_'.$ajax_name, array( $this, 'ovabrw_wcfm_'.$ajax_name ) );
			}
		}

		public function ovabrw_wcfm_get_custom_tax_in_cat() {
			$checked_tax 		= isset( $_POST['checked_tax'] ) ?  $_POST['checked_tax'] : '';
			$list_tax_values 	= array();
			
			if ( $checked_tax ) {
				foreach ( $checked_tax as $key => $term_id ) {
					$ovabrw_custom_tax = get_term_meta( $term_id, 'ovabrw_custom_tax', true );
					
					if ( $ovabrw_custom_tax ) {
						foreach ( $ovabrw_custom_tax as $key => $value ) {
							if ( ! in_array( $value, $list_tax_values ) ) {
								if ( $value ) {
									array_push( $list_tax_values, $value);
								}
							}
						}
					}
				}
			}
			
			echo implode( ',', $list_tax_values ); 
			
			wp_die();
		}

		public function ovabrw_wcfm_get_order_list() {
			$order_query 	= isset( $_POST['order_query'] ) ?  $_POST['order_query'] : '';
			$paged 			= isset( $_POST['paged'] ) ?  $_POST['paged'] : 1;
			$total_pages 	= 0;

			ob_start();
			if ( $order_query ) {
				$order_query['paged'] = $paged;

				if ( isset( $order_query['post__in'] ) && $order_query['post__in'] ) {
					$order_ids 	= (array) $order_query['post__in'];
					$per_page 	= isset( $order_query['posts_per_page'] ) ? (int) $order_query['posts_per_page'] : 1;
					$total_pages = ceil( count( $order_ids ) / $per_page );
				}

				$orders = wc_get_orders( $order_query );

				if ( ! empty( $orders ) && is_array( $orders ) ) {
					foreach ( $orders as $order ) {
						// Order ID
						$order_id = $order->get_id();

						// Custom name
						$buyer = '';

						if ( $order->get_billing_first_name() || $order->get_billing_last_name() ) {
							/* translators: 1: first name 2: last name */
							$buyer = trim( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), $order->get_billing_first_name(), $order->get_billing_last_name() ) );
						} elseif ( $order->get_billing_company() ) {
							$buyer = trim( $order->get_billing_company() );
						} elseif ( $order->get_customer_id() ) {
							$user  = get_user_by( 'id', $order->get_customer_id() );
							$buyer = ucwords( $user->display_name );
						}

						foreach ( $order->get_items() as $item_id => $item ) {
							$product = $item->get_product();

							if ( ! $product || ! $product->is_type('ovabrw_car_rental') ) {
								continue;
							}

							$product_id = $product->get_id();

							// Dates
							$pickup_date 	= $item->get_meta( 'ovabrw_pickup_date' );
							$pickoff_date 	= $item->get_meta( 'ovabrw_pickoff_date' );

							// Locations
							$pickup_location 	= $item->get_meta( 'ovabrw_pickup_loc' );
							$dropoff_location 	= $item->get_meta( 'ovabrw_pickoff_loc' );

							// Deposit
							$is_deposit = false;

							if ( isset( $item['ovabrw_deposit_amount_product'] ) && isset( $item['ovabrw_remaining_amount_product'] ) ) {
								$is_deposit = true;

								$remaining_amount = (float) $item['ovabrw_remaining_amount_product'];
								$balance_order_id = isset( $item['ovabrw_remaining_balance_order_id'] ) ? (int) $item['ovabrw_remaining_balance_order_id'] : '';
							}

							// Insurance amount
							$insurance_amount = isset( $item['ovabrw_amount_insurance_product'] ) ? (float) $item['ovabrw_amount_insurance_product'] : '';
							?>
								<tr>
									<td>
										<a href="<?php echo get_wcfm_view_order_url( $order_id ); ?>" target="_blank">
											<?php printf( esc_html__( '#%s', 'ova-brw-wcfm' ), $order_id ); ?>
										</a>
									</td>
									<td>
										<?php echo esc_html( $buyer ); ?>
									</td>
									<td>
									<?php
										if ( $pickup_date && $pickoff_date ) {
											printf( __( '%s @ %s', 'ova-brw-wcfm' ), $pickup_date, $pickoff_date );
										} elseif ( $pickup_date && ! $pickoff_date ) {
											echo esc_html( $pickup_date );
										} elseif ( ! $pickup_date && $pickoff_date ) {
											echo esc_html( $pickoff_date );
										}
									?>
									</td>
									<td>
									<?php
										if ( $pickup_location && $dropoff_location ) {
											printf( __( '%s @ %s', 'ova-brw-wcfm' ), $pickup_location, $dropoff_location );
										} elseif ( $pickup_location && ! $dropoff_location ) {
											echo esc_html( $pickup_location );
										} elseif ( ! $pickup_location && $dropoff_location ) {
											echo esc_html( $dropoff_location );
										}
									?>
									</td>
									<td>
									<?php if ( $is_deposit ): ?>
										<?php if ( $remaining_amount == 0 ): ?>
											<span class="ova_amount_status_insurance_column ova_paid">
												<?php _e( 'Full Payment', 'ova-brw-wcfm' ); ?>
											</span>
										<?php else:
											if ( $balance_order_id ): ?>
												<span class="ova_amount_status_insurance_column ova_paid">
													<?php _e( 'Original Payment', 'ova-brw-wcfm' ); ?>
												</span>
											<?php else: ?>
												<span class="ova_amount_status_insurance_column ova_paid">
													<?php _e( 'Partial Payment', 'ova-brw-wcfm' ); ?>
												</span>
											<?php endif; ?>
										<?php endif; ?>
									<?php endif; ?>
									</td>
									<td>
									<?php if ( $insurance_amount ): ?>
										<span class="ova_amount_status_insurance_column ova_pending">
											<?php _e( 'Received', 'ova-brw-wcfm' ); ?>
										</span>
									<?php else:
										if ( (float) get_post_meta( $product_id, 'ovabrw_amount_insurance', true ) ):
									?>
										<span class="ova_amount_status_insurance_column ova_paid">
											<?php _e( 'Paid for Customers', 'ova-brw-wcfm' ); ?>
										</span>
										<?php endif; ?>
									<?php endif; ?>
									</td>
									<td>
										<a href="<?php echo get_wcfm_edit_product_url( $product_id ); ?>" target="_blank">
											<?php echo get_the_title( $product_id ); ?>
										</a>
									</td>
									<td>
										<select name="update_order_status" class="update_order_status" data-order_id="<?php echo esc_attr( $order_id ); ?>" data-error-per-msg="<?php _e( 'You don\'t have permission to update', 'ova-brw-wcfm' ); ?>" data-error-update-msg="<?php _e( 'Error Update', 'ova-brw-wcfm' ); ?>">
										<?php foreach ( wc_get_order_statuses() as $k => $title ): ?>
											<option value="<?php echo esc_attr( $k ); ?>"<?php selected( $k, 'wc-'.$order->get_status() ); ?>>
												<?php echo esc_html( $title ); ?>
											</option>
										<?php endforeach; ?>
										</select>
									</td>
								</tr>
							<?php
						}
					}
				} else { ?>
					<tr>
						<td colspan="8">
							<?php _e( 'No items found!', 'ova-brw-wcfm' ); ?>
						</td>
					</tr>
				<?php }
			} else { ?>
				<tr>
					<td colspan="8">
						<?php _e( 'No items found!', 'ova-brw-wcfm' ); ?>
					</td>
				</tr>
			<?php }

			$body = ob_get_contents(); 
			ob_end_clean();

			// pagination
			$pagination = '';

			if ( $total_pages ) {
				$pagination = ovabrw_wcfm_pagination_manage_order( $total_pages, $paged );
			}

			echo json_encode( array( 'body' => $body, 'pagination' => $pagination ) );

			wp_die();
		}

		public function ovabrw_wcfm_filter_order() {
			// Get data
			$order_id 			= isset( $_POST['order_id'] ) ? (int) $_POST['order_id'] : '';
			$customer_name 		= isset( $_POST['customer_name'] ) ? trim( $_POST['customer_name'] ) : '';
			$from_date 			= isset( $_POST['from_date'] ) ? strtotime( $_POST['from_date'] ) : '';
			$to_date 			= isset( $_POST['to_date'] ) ? strtotime( $_POST['to_date'] ) : '';
			$pickup_location 	= isset( $_POST['pickup_location'] ) ? trim( $_POST['pickup_location'] ) : '';
			$dropoff_location 	= isset( $_POST['dropoff_location'] ) ? trim( $_POST['dropoff_location'] ) : '';
			$product_id 	= isset( $_POST['product_id'] ) ? (int) $_POST['product_id'] : '';
			$order_status 	= isset( $_POST['order_status'] ) ? $_POST['order_status'] : '';
			$order 			= isset( $_POST['order'] ) ? $_POST['order'] : 'DESC';

			// array query
			$args_query = [];

			if ( $order_id ) $args_query['order_id'] 					= $order_id;
			if ( $customer_name ) $args_query['customer_name'] 			= $customer_name;
			if ( $from_date ) $args_query['from_date'] 					= $from_date;
			if ( $to_date ) $args_query['to_date'] 						= $to_date;
			if ( $pickup_location ) $args_query['pickup_location'] 		= $pickup_location;
			if ( $dropoff_location ) $args_query['dropoff_location'] 	= $dropoff_location;
			if ( $product_id ) $args_query['product_id'] 				= $product_id;
			if ( $order_status ) $args_query['order_status'] 			= $order_status;

			// Init
			$orders = false;
			$order_query = [];

			// posts per page
			$posts_per_page = apply_filters( 'ovabrw_wcfm_order_posts_per_page', 20 );

			// Get order ids
			$order_ids = ovabrw_wcfm_get_order_ids( $args_query );

			if ( ! empty( $order_ids ) && is_array( $order_ids ) ) {
				// Order query
				$order_query = apply_filters( 'ovabrw_wcfm_order_query', array(
					'posts_per_page' 	=> $posts_per_page,
				    'post__in'			=> $order_ids,
				    'paged'				=> 1,
				    'order' 			=> $order,
				    'orderby' 			=> 'ID'
				));

				$orders = wc_get_orders( $order_query );
			}

			ob_start();
			if ( ! empty( $orders ) && is_array( $orders ) ) {
				foreach ( $orders as $order ) {
					// Order ID
					$order_id = $order->get_id();

					// Custom name
					$buyer = '';

					if ( $order->get_billing_first_name() || $order->get_billing_last_name() ) {
						/* translators: 1: first name 2: last name */
						$buyer = trim( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), $order->get_billing_first_name(), $order->get_billing_last_name() ) );
					} elseif ( $order->get_billing_company() ) {
						$buyer = trim( $order->get_billing_company() );
					} elseif ( $order->get_customer_id() ) {
						$user  = get_user_by( 'id', $order->get_customer_id() );
						$buyer = ucwords( $user->display_name );
					}

					foreach ( $order->get_items() as $item_id => $item ) {
						$product = $item->get_product();

						if ( ! $product || ! $product->is_type('ovabrw_car_rental') ) {
							continue;
						}

						$product_id = $product->get_id();

						// Dates
						$pickup_date 	= $item->get_meta( 'ovabrw_pickup_date' );
						$pickoff_date 	= $item->get_meta( 'ovabrw_pickoff_date' );

						// Locations
						$pickup_location 	= $item->get_meta( 'ovabrw_pickup_loc' );
						$dropoff_location 	= $item->get_meta( 'ovabrw_pickoff_loc' );

						// Deposit
						$is_deposit = false;

						if ( isset( $item['ovabrw_deposit_amount_product'] ) && isset( $item['ovabrw_remaining_amount_product'] ) ) {
							$is_deposit = true;

							$remaining_amount = (float) $item['ovabrw_remaining_amount_product'];
							$balance_order_id = isset( $item['ovabrw_remaining_balance_order_id'] ) ? (int) $item['ovabrw_remaining_balance_order_id'] : '';
						}

						// Insurance amount
						$insurance_amount = isset( $item['ovabrw_amount_insurance_product'] ) ? (float) $item['ovabrw_amount_insurance_product'] : '';
						?>
							<tr>
								<td>
									<a href="<?php echo get_wcfm_view_order_url( $order_id ); ?>" target="_blank">
										<?php printf( esc_html__( '#%s', 'ova-brw-wcfm' ), $order_id ); ?>
									</a>
								</td>
								<td>
									<?php echo esc_html( $buyer ); ?>
								</td>
								<td>
								<?php
									if ( $pickup_date && $pickoff_date ) {
										printf( __( '%s @ %s', 'ova-brw-wcfm' ), $pickup_date, $pickoff_date );
									} elseif ( $pickup_date && ! $pickoff_date ) {
										echo esc_html( $pickup_date );
									} elseif ( ! $pickup_date && $pickoff_date ) {
										echo esc_html( $pickoff_date );
									}
								?>
								</td>
								<td>
								<?php
									if ( $pickup_location && $dropoff_location ) {
										printf( __( '%s @ %s', 'ova-brw-wcfm' ), $pickup_location, $dropoff_location );
									} elseif ( $pickup_location && ! $dropoff_location ) {
										echo esc_html( $pickup_location );
									} elseif ( ! $pickup_location && $dropoff_location ) {
										echo esc_html( $dropoff_location );
									}
								?>
								</td>
								<td>
								<?php if ( $is_deposit ): ?>
									<?php if ( $remaining_amount == 0 ): ?>
										<span class="ova_amount_status_insurance_column ova_paid">
											<?php _e( 'Full Payment', 'ova-brw-wcfm' ); ?>
										</span>
									<?php else:
										if ( $balance_order_id ): ?>
											<span class="ova_amount_status_insurance_column ova_paid">
												<?php _e( 'Original Payment', 'ova-brw-wcfm' ); ?>
											</span>
										<?php else: ?>
											<span class="ova_amount_status_insurance_column ova_paid">
												<?php _e( 'Partial Payment', 'ova-brw-wcfm' ); ?>
											</span>
										<?php endif; ?>
									<?php endif; ?>
								<?php endif; ?>
								</td>
								<td>
								<?php if ( $insurance_amount ): ?>
									<span class="ova_amount_status_insurance_column ova_pending">
										<?php _e( 'Received', 'ova-brw-wcfm' ); ?>
									</span>
								<?php else:
									if ( (float) get_post_meta( $product_id, 'ovabrw_amount_insurance', true ) ):
								?>
									<span class="ova_amount_status_insurance_column ova_paid">
										<?php _e( 'Paid for Customers', 'ova-brw-wcfm' ); ?>
									</span>
									<?php endif; ?>
								<?php endif; ?>
								</td>
								<td>
									<a href="<?php echo get_wcfm_edit_product_url( $product_id ); ?>" target="_blank">
										<?php echo get_the_title( $product_id ); ?>
									</a>
								</td>
								<td>
									<select name="update_order_status" class="update_order_status" data-order_id="<?php echo esc_attr( $order_id ); ?>" data-error-per-msg="<?php _e( 'You don\'t have permission to update', 'ova-brw-wcfm' ); ?>" data-error-update-msg="<?php _e( 'Error Update', 'ova-brw-wcfm' ); ?>">
									<?php foreach ( wc_get_order_statuses() as $k => $title ): ?>
										<option value="<?php echo esc_attr( $k ); ?>"<?php selected( $k, 'wc-'.$order->get_status() ); ?>>
											<?php echo esc_html( $title ); ?>
										</option>
									<?php endforeach; ?>
									</select>
								</td>
							</tr>
						<?php
					}
				}
			} else { ?>
				<tr>
					<td colspan="8">
						<?php _e( 'No items found!', 'ova-brw-wcfm' ); ?>
					</td>
				</tr>
			<?php }
			$body = ob_get_contents(); 
			ob_end_clean();

			// pagination
			$pagination 	= '';
			$total_pages 	= ceil( count( $order_ids ) / $posts_per_page );

			if ( count( $order_ids ) ) {
				$pagination = ovabrw_wcfm_pagination_manage_order( $total_pages, 1 );
			}

			echo json_encode( array(
				'body' 			=> $body,
				'pagination' 	=> $pagination,
				'query' 		=> json_encode( $order_query )
			));

			wp_die();
		}

		public function ovabrw_wcfm_update_order_status() {
			$order_id 		= isset( $_POST['order_id'] ) ? sanitize_text_field( $_POST['order_id'] ) : '';
			$order_status 	= isset( $_POST['new_order_status'] ) ? sanitize_text_field( $_POST['new_order_status'] ) : ''  ;

			if ( $order_id && $order_status ) {

				$order = wc_get_order( $order_id );

				if ( ! wcfm_is_vendor() ) {
					echo 'error_permission';	
				} elseif ( $order->update_status( $order_status ) ) {
					echo 'true';
				} else {
					echo 'false';
				}
			} else {
				echo 'false';
			}
			
			wp_die();
		}
	}

	return new OVABRW_WCFM_Ajaxs();
}