<?php defined( 'ABSPATH' ) || exit();

// Return real path template in Plugin or Theme
if ( ! function_exists( 'ovabrw_wcfm_locate_template' ) ) {
	function ovabrw_wcfm_locate_template( $template_name, $template_path = '', $default_path = '' ) {
		// Set variable to search in ovabrw-templates folder of theme.
		if ( ! $template_path ) $template_path = 'ovabrw-wcfm-templates/';

		// Set default plugin templates path.
		if ( ! $default_path ) $default_path = OVABRW_WCFM_PLUGIN_PATH . 'ovabrw-wcfm-templates/';

		// Search template file in theme folder.
		$template = locate_template( array( $template_path . $template_name ));

		// Get plugins template file.
		if ( ! $template ) $template = $default_path . $template_name;

		return apply_filters( 'ovabrw_wcfm_locate_template', $template, $template_name, $template_path, $default_path );
	}
}

// Include Template File
if ( ! function_exists( 'ovabrw_wcfm_get_template' ) ) {
	function ovabrw_wcfm_get_template( $template_name, $args = array(), $tempate_path = '', $default_path = '' ) {
		if ( is_array( $args ) && isset( $args ) ) extract( $args );

		$template_file = ovabrw_wcfm_locate_template( $template_name, $tempate_path, $default_path );

		if ( ! file_exists( $template_file ) ) {
			_doing_it_wrong( __FUNCTION__, sprintf( '<code>%s</code> does not exist.', $template_file ), '1.0.0' );
			return;
		}
		
		include $template_file;
	}
}

/**
 * Get product ids by vendor id
 * @param  int $vendor_id
 * @return array $product_ids
 */
if ( ! function_exists( 'get_product_ids_by_vendor' ) ) {
	function get_product_ids_by_vendor( $vendor_id ){
	    $args = array(
	        'post_type' 		=> 'product',
	        'posts_per_page' 	=> '-1',
	        'post_status'   	=> 'publish',
	        'fields'            => 'ids', 
            'tax_query'         => array(
                array(
                    'taxonomy' => 'product_type',
                    'field'    => 'slug',
                    'terms'    => 'ovabrw_car_rental', 
                ),
            )
	    );

	    // Check wcfm_is_vendor
	    if ( function_exists( 'wcfm_is_vendor' ) && wcfm_is_vendor( $vendor_id ) ) {
	    	$args['author'] = $vendor_id;
	    }

	    $product_ids = get_posts( $args );

	    return apply_filters( 'ovabrw_wcfm_get_product_ids_by_vendor', $product_ids, $vendor_id );
	}
}

/**
 * Get Order ID of a vendor
 */
if ( ! function_exists( 'get_order_vendors' ) ) {
	function get_order_vendors( $author_id, $post ) {
		global $wpdb; //This is used only if making any database queries

		$order_ids = array();

		$filter_order_status =  isset( $post['filter_order_status'] ) ? sanitize_text_field( $post['filter_order_status'] ) : '';

		if( ! empty( $filter_order_status ) ){
		    $order_status = array($filter_order_status);
		}else{
		    $order_status = array( 'wc-processing','wc-completed', 'wc-half-completed', 'wc-on-hold', 'wc-cancelled', 'wc-closed' );    
		}


		$room_query = ( isset( $post['room_id'] ) && $post['room_id'] != '' ) ? 'AND order_item_meta.meta_value = '. sanitize_text_field( $post['room_id'] ) : '';

		$order_number = isset( $post['order_number'] ) ? (int)( $post['order_number'] ) : '';
		$name_customer = isset( $post['name_customer'] ) ? sanitize_text_field( $post['name_customer'] ) : '';

		$result = $wpdb->get_col("
		    SELECT Distinct order_items.order_id
		    FROM {$wpdb->prefix}woocommerce_order_items as order_items
		    LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
		    LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
		    WHERE posts.post_type = 'shop_order'
		    AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
		    AND order_items.order_item_type = 'line_item'
		    AND order_item_meta.meta_key = '_product_id'
		    $room_query


		");

		$room_code_filter = isset( $post['room_code'] ) ? sanitize_text_field( $post['room_code'] ) : '';

		$from_day = isset( $post['from_day'] ) ? strtotime( $post['from_day'] ) : '';
		$to_day = isset( $post['to_day'] ) ? strtotime( $post['to_day'] ) : '';

		$check_in_out = isset( $post['check_in_out'] ) ? sanitize_text_field( $post['check_in_out'] ) : '';
		$check = $check_in_flag = $check_out_flag = $pickup_loc_flag = $pickoff_loc_flag = true;

		$current_pickup_loc = isset( $post['pickup_loc'] ) ? sanitize_text_field( $post['pickup_loc'] ) : '';
		$current_pickoff_loc = isset( $post['pickoff_loc'] ) ? sanitize_text_field( $post['pickoff_loc'] ) : '';

		$ovabrw_date_format = ovabrw_get_date_format();
		$ovabrw_time_format = ovabrw_get_time_format_php();


		$ovabrw_date_time_format = $ovabrw_date_format . ' ' . $ovabrw_time_format;


		foreach ($result as $key => $value) {

		    $order = wc_get_order($value);

		    $fullname = $order->get_formatted_billing_full_name();
		    
		    $is_vendor = false;

		    if( ( empty( $order_number ) || ( ! empty( $order_number ) && $order_number == $value  ) ) && ( empty( $name_customer ) || ( strpos($fullname, $name_customer) ) !== false ) ) {

		        // Get Order Detail by Order ID
		        $order = wc_get_order($value);

		        

		        // Get Meta Data type line_item of Order
		        $order_line_items = $order->get_items( apply_filters( 'woocommerce_purchase_order_item_types', 'line_item' ) );

		        // For Meta Data
		        foreach ( $order_line_items as $item_id => $item ) {

		            $room_check_in = $room_check_out = $room_code = $pickup_loc = $pickoff_loc = '';
		            
		            $room_name = $item->get_name();

		            
		            // Get value of check-in, check-out
		            foreach ( $item->get_formatted_meta_data() as $meta_id => $meta ) {

		                if( $meta->key == 'ovabrw_pickup_date' ){
		                    $room_check_in = date( $ovabrw_date_time_format, strtotime( $meta->value ) );
		                }
		                if( $meta->key == 'ovabrw_pickoff_date' ){
		                    $room_check_out = date( $ovabrw_date_time_format, strtotime( $meta->value ) );
		                }
		               

		                if( $meta->key == 'ovabrw_pickup_loc' ){
		                    $pickup_loc = $meta->value;
		                }
		                if( $meta->key == 'ovabrw_pickoff_loc' ){
		                    $pickoff_loc = $meta->value;

		                }

		            }

		            // Check vendor id like current user id
		            $line_item = new WC_Order_Item_Product( $item );
					$product  = $line_item->get_product();
					$product_id = $line_item->get_product_id();
					$vendor_id  = wcfm_get_vendor_id_by_post( $product_id );

					if( $vendor_id && $vendor_id == $author_id ){
						$is_vendor = true;
					}

		            $room_check_in_timep = strtotime( $room_check_in );
		            $room_check_out_timep = strtotime( $room_check_out );

		            if( $check_in_out == 'check_in' && $from_day != '' && $to_day != '' ){
		                $check = ( $from_day <=  $room_check_in_timep && $room_check_in_timep <= $to_day ) ? true : false;
		            }else if( $check_in_out == 'check_out' ){
		                $check = ( $from_day <=  $room_check_out_timep &&  $room_check_out_timep <= $to_day ) ? true : false;
		            }else if( $from_day != '' && $to_day != '' ){
		                $check_in_flag = ( $from_day <=  $room_check_in_timep && $room_check_in_timep <= $to_day ) ? true : false;
		                $check_out_flag = ( $from_day <=  $room_check_out_timep &&  $room_check_out_timep <= $to_day ) ? true : false;
		            }

		            if( $current_pickup_loc != '' && $pickup_loc != $current_pickup_loc ){
		                $pickup_loc_flag = false;
		            }else{
		                $pickup_loc_flag = true;
		            }

		            if( $current_pickoff_loc != '' && $pickoff_loc != $current_pickoff_loc ){
		                $pickoff_loc_flag = false;
		            }else{
		                $pickoff_loc_flag = true;
		            }

		            $order_amount_insurance = $item['ovabrw_amount_insurance_product'];
		            if ($order_amount_insurance == 0) {
		                $status_insurance = '<span class="ova_amount_status_insurance_column ova_paid">'.esc_html__("Paid for Customers", "ova-brw").'</span>';
		            } else {
		                $status_insurance = '<span class="ova_amount_status_insurance_column ova_pending">'.esc_html__("Received", "ova-brw").'</span>';
		            }
		            $order_amount_remaining = $item['ovabrw_remaining_amount_product'];
		            if ($order_amount_remaining == 0) {
		                $status_deposit = '<span class="ova_amount_status_insurance_column ova_paid">'.esc_html__("Full Payment", "ova-brw").'</span>';
		            } else {
		                $status_deposit = '<span class="ova_amount_status_insurance_column ova_pending">'.esc_html__("Partial Payment", "ova-brw").'</span>';
		            }

		            
		            if( empty( $pickup_loc ) && empty( $pickoff_loc ) ) {
		                $pickup_off_loc =  '';
		            } else {
		                $pickup_off_loc =  $pickup_loc . ' @ ' . $pickoff_loc;
		            }


		            if(  $check && $check_in_flag && $check_out_flag && $pickup_loc_flag && $pickoff_loc_flag && $is_vendor && !in_array($order->get_ID(), $order_ids) ){

		            	array_push( $order_ids, $order->get_ID() );

		            }
		            
		            
		        }

		    }
		}


		return $order_ids;
	}
}

/**
 * Pagination manage order
 */
if ( ! function_exists( 'ovabrw_wcfm_pagination_manage_order' ) ) {
	function ovabrw_wcfm_pagination_manage_order( $total, $paged = null ) {
		$current_page = $paged ? $paged : 1;

		$html = '<nav class="ovabrw-wcfm-pagination">';
		$html .= paginate_links( apply_filters( 'ova_brw_wfcm_pagination_args', array(
			'base'         => esc_url_raw( str_replace( 999999999, '%#%', get_pagenum_link( 999999999, false ) ) ),
			'format'       => '',
			'add_args'     => '',
			'current'      => max( 1,  $current_page),
			'total'        => $total,
			'prev_text'    => esc_html__( 'Previous', 'ova-brw-wcfm' ),
			'next_text'    => esc_html__( 'Next', 'ova-brw-wcfm' ),
			'type'         => 'list',
			'end_size'     => 1,
			'mid_size'     => 2
		)));

		$html .= '</nav>';

		return $html;
	}
}

/**
 * Get order ids
 */
if ( ! function_exists( 'ovabrw_wcfm_get_order_ids' ) ) {
	function ovabrw_wcfm_get_order_ids( $args = [] ) {
		global $wpdb;

		// Get data
		$user_id 			= isset( $args['user_id'] ) ? (int) $args['user_id'] : get_current_user_id();
		$order_id 			= isset( $args['order_id'] ) ? (int) $args['order_id'] : '';
		$customer_name 		= isset( $args['customer_name'] ) ? trim( $args['customer_name'] ) : '';
		$from_date 			= isset( $args['from_date'] ) ? (int) $args['from_date'] : '';
		$to_date 			= isset( $args['to_date'] ) ? (int) $args['to_date'] : '';
		$pickup_location 	= isset( $args['pickup_location'] ) ? trim( $args['pickup_location'] ) : '';
		$dropoff_location 	= isset( $args['dropoff_location'] ) ? trim( $args['dropoff_location'] ) : '';
		$product_id 		= isset( $args['product_id'] ) ? (int) $args['product_id'] : '';
		$order_status 		= isset( $args['order_status'] ) ? (array) $args['order_status'] : array_keys( wc_get_order_statuses() );

		// Product ID query
		$product_query = $product_id ? 'AND oitem_meta.meta_value = '. $product_id : '';

		// Get order ids
		$results = $order_ids = [];

		if ( ovabrw_wc_custom_orders_table_enabled() ) {
			// Order ID query
			$order_query = $order_id ? 'AND o.id = '. $order_id : '';

            $results = $wpdb->get_col("
                SELECT DISTINCT o.id
                FROM {$wpdb->prefix}wc_orders AS o
                LEFT JOIN {$wpdb->prefix}woocommerce_order_items AS oitems
                ON o.id = oitems.order_id
                LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta AS oitem_meta
                ON oitems.order_item_id = oitem_meta.order_item_id
                WHERE oitems.order_item_type = 'line_item'
                AND oitem_meta.meta_key = '_product_id'
                AND o.status IN ( '" . implode( "','", $order_status ) . "' )
                $product_query
                $order_query
                ORDER BY o.id DESC
            ");
        } else {
        	// Order ID query
			$order_query = $order_id ? 'AND oitems.order_id = '. $order_id : '';

            $results = $wpdb->get_col("
                SELECT DISTINCT oitems.order_id
                FROM {$wpdb->prefix}woocommerce_order_items AS oitems
                LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta AS oitem_meta
                ON oitems.order_item_id = oitem_meta.order_item_id
                LEFT JOIN {$wpdb->posts} AS posts ON oitems.order_id = posts.ID
                WHERE posts.post_type = 'shop_order'
                AND oitems.order_item_type = 'line_item'
                AND oitem_meta.meta_key = '_product_id'
                AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
                $product_query
                $order_query
                ORDER BY oitems.order_id DESC
            ");
        }

        // Filter order ids
        if ( ! empty( $results ) && is_array( $results ) ) {
        	foreach ( $results as $k => $ord_id ) {
        		$order 		= wc_get_order( $ord_id );
        		$has_rental = $is_vendor = $vendor_has_product = false;
        		$check_date = $check_location = true;

        		// Check custom name
        		if ( $customer_name ) {
        			// Custom name
					$buyer = '';

					if ( $order->get_billing_first_name() || $order->get_billing_last_name() ) {
						/* translators: 1: first name 2: last name */
						$buyer = trim( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), $order->get_billing_first_name(), $order->get_billing_last_name() ) );
					} elseif ( $order->get_billing_company() ) {
						$buyer = trim( $order->get_billing_company() );
					} elseif ( $order->get_customer_id() ) {
						$user  = get_user_by( 'id', $order->get_customer_id() );
						$buyer = ucwords( $user->display_name );
					}

					if ( strpos( $buyer, $customer_name ) === false ) {
						continue;
					}
        		}

        		// check is vendor
        		if ( function_exists( 'wcfm_is_vendor' ) && wcfm_is_vendor( $user_id ) ) {
        			$is_vendor = true;
        		}

        		// order items
        		foreach ( $order->get_items() as $item_id => $item ) {
        			$product = $item->get_product();

					if ( $product && $product->is_type('ovabrw_car_rental') ) {
						$has_rental = true;
					}

					// product id
					$product_id = $product->get_id();

					// dates
					$pickup_date 	= strtotime( $item->get_meta( 'ovabrw_pickup_date' ) );
					$pickoff_date 	= strtotime( $item->get_meta( 'ovabrw_pickoff_date' ) );

					// locations
					$pickup_loc 	= trim( $item->get_meta( 'ovabrw_pickup_loc' ) );
					$dropoff_loc 	= trim( $item->get_meta( 'ovabrw_pickoff_loc' ) );

					// check product id
					if ( $is_vendor ) {
						if ( function_exists( 'wcfm_get_vendor_id_by_post' ) ) {
							$vendor_id = wcfm_get_vendor_id_by_post( $product_id );

							if ( $vendor_id == $user_id ) $vendor_has_product = true;
						}
					}

					// check dates
					if ( $from_date && $to_date ) {
						if ( $from_date > $pickup_date || $to_date < $pickoff_date ) {
							$check_date = false;
						}
					} elseif ( $from_date && ! $to_date ) {
						if ( $from_date < $pickup_date || $from_date > $pickoff_date ) {
							$check_date = false;
						}
					} elseif ( ! $from_date && $to_date ) {
						if ( $to_date < $pickup_date || $to_date > $pickoff_date ) {
							$check_date = false;
						}
					}

					// check locations
					if ( $pickup_location && $dropoff_location ) {
						$pickup_location_title 	= trim( get_the_title( $pickup_location ) );
						$dropoff_location_title = trim( get_the_title( $dropoff_location ) );

						if ( $pickup_location_title != $pickup_loc || $dropoff_location_title != $dropoff_loc ) {
							$check_location = false;
						}
					} elseif ( $pickup_location && ! $dropoff_location ) {
						$pickup_location_title 	= trim( get_the_title( $pickup_location ) );

						if ( $pickup_location_title != $pickup_loc ) {
							$check_location = false;
						}
					} elseif ( ! $pickup_location && $dropoff_location ) {
						$dropoff_location_title = trim( get_the_title( $dropoff_location ) );
						
						if ( $dropoff_location_title != $dropoff_loc ) {
							$check_location = false;
						}
					}
        		}

        		// Remove order id
        		if ( ! $has_rental ) continue;
        		if ( $is_vendor && ! $vendor_has_product ) continue;
        		if ( ! $check_date ) continue;
        		if ( ! $check_location ) continue;

        		array_push( $order_ids, $ord_id );
        	}
        }

        return apply_filters( 'ovabrw_wcfm_get_order_ids', $order_ids, $args );
	}
}