<?php defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'OVABRW_WCFM_Menus', false ) ) {

	class OVABRW_WCFM_Menus {

		protected static $_instance = null;

		public function __construct() {
			add_filter( 'wcfm_query_vars', array( $this, 'ovabrw_wcfm_query_vars' ), 50 );
			add_filter( 'wcfm_endpoint_title', array( $this, 'ovabrw_wcfm_endpoint_title' ), 50, 2 );
			add_action( 'init', array( $this, 'ovabrw_wcfm_init' ), 50 );
			add_filter( 'wcfm_endpoints_slug', array( $this, 'ovabrw_wcfm_menus_endpoints_slug' ) );
			add_filter( 'wcfm_menus', array( $this, 'ovabrw_wcfm_menus' ), 20 );
			add_action( 'wcfm_load_views', array( $this, 'ovabrw_wcfm_csm_load_views' ), 50 );
			add_action( 'before_wcfm_load_views', array( $this, 'ovabrw_wcfm_csm_load_views' ), 50 );
		}

		/**
		 * instance
		 * @return object
		 */
		public static function instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

		/**
		 * Menus Query Var
		 * @param  array $query_vars
		 * @return array $query_vars
		 */
		public function ovabrw_wcfm_query_vars( $query_vars ) {
			$wcfm_modified_endpoints = (array) get_option( 'wcfm_endpoints' );
	
			$query_menus_vars = array(
				'wcfm-create-order' 	=> ! empty( $wcfm_modified_endpoints['wcfm-create-order'] ) ? $wcfm_modified_endpoints['wcfm-create-order'] : 'create-order',
				'wcfm-manage-order' 	=> ! empty( $wcfm_modified_endpoints['wcfm-manage-order'] ) ? $wcfm_modified_endpoints['wcfm-manage-order'] : 'manage-order',
				'wcfm-calendar' 		=> ! empty( $wcfm_modified_endpoints['wcfm-calendar'] ) ? $wcfm_modified_endpoints['wcfm-calendar'] : 'calendar'
			);
			
			$query_vars = array_merge( $query_vars, $query_menus_vars );
			
			return $query_vars;
		}

		/**
		 * Menus End Point Title
		 * @param  string $title
		 * @param  string $endpoint
		 * @return string $title
		 */
		public function ovabrw_wcfm_endpoint_title( $title, $endpoint ) {
			switch ( $endpoint ) {
				case 'wcfm-create-order' :
					$title = __( 'Create Order', 'ova-brw-wcfm' );
				break;
				
				case 'wcfm-manage-order' :
					$title = __( 'Manage Order', 'ova-brw-wcfm' );
				break;
				
				case 'wcfm-calendar' :
					$title = __( 'Calendar', 'ova-brw-wcfm' );
				break;
			}
			
			return $title;
		}

		/**
		 * Menus Endpoint Intialize
		 */
		public function ovabrw_wcfm_init() {
			global $WCFM_Query;

			// Intialize WCFM End points
			$WCFM_Query->init_query_vars();
			$WCFM_Query->add_endpoints();
			
			if ( ! get_option( 'wcfm_updated_end_point_cms' ) ) {
				// Flush rules after endpoint update
				flush_rewrite_rules();
				update_option( 'wcfm_updated_end_point_cms', 1 );
			}
		}

		/**
		 * Menus Endpoiint Edit
		 * @param  array $endpoints
		 * @return array $endpoints
		 */
		public function ovabrw_wcfm_menus_endpoints_slug( $endpoints ) {
			$menus_endpoints = array(
				'wcfm-create-order' 	=> 'create-order',
				'wcfm-manage-order' 	=> 'manage-order',
				'wcfm-calendar' 		=> 'calendar'
			);
	
			$endpoints = array_merge( $endpoints, $menus_endpoints );
			
			return $endpoints;
		}

		/**
		 * Add new menus
		 * @param  array $menus
		 * @return array $menus
		 */
		public function ovabrw_wcfm_menus( $menus ) {
			$new_menus = array( 
				'wcfm-create-order' => array(
					'label'  	=> esc_html__( 'Create Order', 'ova-brw-wcfm' ),
					'url'       => $this->ovabrw_get_wcfm_menus_url( 'wcfm-create-order' ),
					'icon'      => 'shopping-basket',
					'priority'  => 6,
				),
				'wcfm-manage-order' => array(
					'label'  	=> esc_html__( 'Manage Order', 'ova-brw-wcfm' ),
					'url'       => $this->ovabrw_get_wcfm_menus_url( 'wcfm-manage-order' ),
					'icon'      => 'shopping-bag',
					'priority'  => 7,
				),
				'wcfm-calendar' => array(
					'label'  	=> esc_html__( 'Calendar', 'ova-brw-wcfm' ),
					'url'       => $this->ovabrw_get_wcfm_menus_url( 'wcfm-calendar' ),
					'icon'      => 'calendar-check',
					'priority'  => 8
				)
			);
	
			$menus = array_merge( $menus, $new_menus );
				
			return $menus;
		}

		/**
		 * Menus Views
		 * @param  string $end_point
		 */
		public function ovabrw_wcfm_csm_load_views( $end_point ) {
			switch( $end_point ) {
				case 'wcfm-create-order':
					require_once( OVABRW_WCFM_PLUGIN_PATH . 'views/wcfm-views-create-order.php' );
				break;

				case 'wcfm-manage-order':
					require_once( OVABRW_WCFM_PLUGIN_PATH . 'views/wcfm-views-manage-order.php' );
				break;

				case 'wcfm-calendar':
					require_once( OVABRW_WCFM_PLUGIN_PATH . 'views/wcfm-views-calendar.php' );
				break;
			}
		}

		/**
		 * Get Menu URL
		 * @param  string $endpoint
		 * @return string $menus_url
		 */
		public function ovabrw_get_wcfm_menus_url( $endpoint ) {
			global $WCFM;
			$wcfm_page = get_wcfm_page();
			$menus_url = wcfm_get_endpoint_url( $endpoint, '', $wcfm_page );

			return $menus_url;
		}
	}

	return new OVABRW_WCFM_Menus();
}