<?php if ( ! defined( 'ABSPATH' ) ) exit();

$products           = get_product_ids_by_vendor( get_current_user_id() );
$date_format        = ovabrw_get_date_format();
$datetime_format    = ovabrw_get_date_format().' '.ovabrw_get_time_format_php();

// Defautl country
$country_setting    = get_option( 'woocommerce_default_country', 'US:CA' );

if ( strstr( $country_setting, ':' ) ) {
    $country_setting = explode( ':', $country_setting );
    $country         = current( $country_setting );
    $state           = end( $country_setting );
} else {
    $country = $country_setting;
    $state   = '*';
}

$action = get_wcfm_page().'create-order/';

?>
<div class="wrap">
    <form action="<?php echo esc_url( $action ); ?>" id="booking-filter" class="ovabrw-create-order" method="POST" enctype="multipart/form-data">
        <h2><?php esc_html_e( 'Create Order', 'ova-brw-wcfm' ); ?></h2>
        <div class="ovabrw-wrap">
            <?php
            // Multi currency
            $currencies = [];

            if ( is_plugin_active( 'woo-multi-currency/woo-multi-currency.php' ) ) {
                $setting    = WOOMULTI_CURRENCY_F_Data::get_ins();
                $currencies = $setting->get_list_currencies();
            }

            if ( is_plugin_active( 'woocommerce-multilingual/wpml-woocommerce.php' ) ) {
                // WPML multi currency
                global $woocommerce_wpml;

                if ( $woocommerce_wpml && is_object( $woocommerce_wpml ) ) {
                    if ( wp_doing_ajax() ) add_filter( 'wcml_load_multi_currency_in_ajax', '__return_true' );

                    $currencies     = $woocommerce_wpml->get_setting( 'currency_options' );
                    $current_lang   = apply_filters( 'wpml_current_language', NULL );

                    if ( $current_lang != 'all' && ! empty( $currencies ) && is_array( $currencies ) ) {
                        foreach ( $currencies as $k => $data ) {
                            if ( isset( $currencies[$k]['languages'][$current_lang] ) && $currencies[$k]['languages'][$current_lang] ) {
                                continue;
                            } else {
                                unset( $currencies[$k] );
                            }
                        }
                    }
                }
            }

            if ( ! empty( $currencies ) && is_array( $currencies ) ):
                $current_currency = isset( $_GET['currency'] ) && $_GET['currency'] ? $_GET['currency'] : '';

                if ( ! $current_currency ) $current_currency = array_key_first( $currencies ); 
            ?>
                <div class="ovabrw-row ovabrw-order-currency">
                    <label for="ovabrw-currency"><?php esc_html_e( 'Currency', 'ova-brw-wcfm' ); ?></label>
                    <select name="currency" id="ovabrw-currency">
                <?php
                foreach ( $currencies as $currency => $rate ): ?>
                    <option value="<?php echo esc_attr( $currency ); ?>"<?php selected( $currency, $current_currency ); ?>>
                        <?php esc_html_e( $currency ); ?>
                    </option>
                <?php endforeach; ?>
                    </select>
                    <input
                        type="hidden"
                        name="ovabrw-admin-url"
                        value="<?php echo esc_url( get_admin_url() ); ?>"
                    />
                </div>
            <?php endif; ?>
            <div class="ovabrw-row ovabrw-order-status">
                <select name="status_order" id="stattus-order" required>
                    <option value="">
                        <?php esc_html_e( 'Select status', 'ova-brw-wcfm' ); ?>
                    </option>
                    <option value="completed">
                        <?php esc_html_e( 'Completed', 'ova-brw-wcfm' ); ?>
                    </option>
                    <option value="processing">
                        <?php esc_html_e( 'Processing', 'ova-brw-wcfm' ); ?>
                    </option>
                    <option value="pending">
                        <?php esc_html_e( 'Pending payment', 'ova-brw-wcfm' ); ?>
                    </option>
                    <option value="on-hold">
                        <?php esc_html_e( 'On hold', 'ova-brw-wcfm' ); ?>
                    </option>
                    <option value="cancelled">
                        <?php esc_html_e( 'Cancelled', 'ova-brw-wcfm' ); ?>
                    </option>
                    <option value="refunded">
                        <?php esc_html_e( 'Refunded', 'ova-brw-wcfm' ); ?>
                    </option>
                    <option value="failed">
                        <?php esc_html_e( 'Failed', 'ova-brw-wcfm' ); ?>
                    </option>
                </select>
            </div>
            <div class="ovabrw-row ova-column-3 ovabrw-billing">
                <?php do_action( 'ovabrw_before_create_new_order_billing' ); ?>
                <div class="item">
                    <input
                        type="text"
                        name="ovabrw_first_name"
                        placeholder="<?php esc_html_e( 'First Name', 'ova-brw-wcfm' ); ?>"
                        required
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ovabrw_last_name"
                        placeholder="<?php esc_html_e( 'Last Name', 'ova-brw-wcfm' ); ?>"
                        required
                    />
                </div>
                <div class="item">
                    <input
                        type="email"
                        name="ovabrw_email"
                        placeholder="<?php esc_html_e( 'Email', 'ova-brw-wcfm' ); ?>"
                        required
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ovabrw_phone"
                        placeholder="<?php esc_html_e( 'Phone', 'ova-brw-wcfm' ); ?>"
                        required
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ovabrw_company"
                        placeholder="<?php esc_html_e( 'Company', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ovabrw_address_1"
                        placeholder="<?php esc_html_e( 'Address 1', 'ova-brw-wcfm' ); ?>"
                        required
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ovabrw_address_2"
                        placeholder="<?php esc_html_e( 'Address 2', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ovabrw_city"
                        placeholder="<?php esc_html_e( 'City', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <select name="ovabrw_country" class="ovabrw_country" style="width: 100%;" required>
                        <?php WC()->countries->country_dropdown_options( $country, $state ); ?>
                    </select>
                </div>
                <?php do_action( 'ovabrw_after_create_new_order_billing' ); ?>
            </div>
            <div class="ship-to-different-address">
                <label>
                    <input
                        id="ship-to-different-address-checkbox"
                        class="ship-to-different-address-checkbox input-checkbox"
                        type="checkbox"
                        name="ship_to_different_address"
                        value="1"
                    />
                    <span><?php echo esc_html_e( 'Ship to a different address?', 'ova-brw-wcfm' ); ?></span>
                </label>
            </div>
            <div class="ovabrw-row ova-column-3 ovabrw-shipping">
                <?php do_action( 'ovabrw_before_create_new_order_shipping' ); ?>
                <div class="item">
                    <input
                        type="text"
                        name="ship_ovabrw_first_name"
                        placeholder="<?php esc_html_e( 'First Name', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ship_ovabrw_last_name"
                        placeholder="<?php esc_html_e( 'Last Name', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ship_ovabrw_phone"
                        placeholder="<?php esc_html_e( 'Phone', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ship_ovabrw_company"
                        placeholder="<?php esc_html_e( 'Company', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ship_ovabrw_address_1"
                        placeholder="<?php esc_html_e( 'Address 1', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ship_ovabrw_address_2"
                        placeholder="<?php esc_html_e( 'Address 2', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <input
                        type="text"
                        name="ship_ovabrw_city"
                        placeholder="<?php esc_html_e( 'City', 'ova-brw-wcfm' ); ?>"
                    />
                </div>
                <div class="item">
                    <select name="ship_ovabrw_country" class="ovabrw_country" style="width: 100%;">
                        <?php WC()->countries->country_dropdown_options( $country, $state ); ?>
                    </select>
                </div>
                <?php do_action( 'ovabrw_after_create_new_order_shipping' ); ?>
            </div>
            <div class="wrap_item">
                <div class="ovabrw-order">
                    <div class="item">
                        <div class="sub-item">
                            <h3 class="title"><?php esc_html_e(  'Product', 'ova-brw-wcfm' ); ?></h3>
                            <div class="rental_item">
                                <label for="ovabrw-name-product">
                                    <?php esc_html_e( 'Name Product', 'ova-brw-wcfm' ); ?>
                                </label>
                                <select
                                    id="ovabrw-name-product"
                                    class="ovabrw_name_product"
                                    name="ovabrw_name_product[]"
                                    data-symbol="<?php echo esc_attr( get_woocommerce_currency_symbol() ); ?>"
                                    data-date_format="<?php echo esc_attr( $datetime_format ); ?>"
                                    data-short_date_format="<?php echo esc_attr( $date_format ); ?>"
                                    required>
                                    <option value=""><?php esc_html_e( 'Select Product', 'ova-brw-wcfm' ); ?></option>
                                    <?php foreach ( $products as $product_id ): ?>
                                        <option value="<?php echo esc_attr( $product_id ); ?>">
                                            <?php echo esc_html( get_the_title( $product_id ) ); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                                <div class="ovabrw-rental-type-loading">
                                    <span class="dashicons-before dashicons-update-alt"></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <span class="button ovabrw-remove-order-item">x</span>
                </div>
            </div>
            <div class="ovabrw-row">
                <button class="button ovabrw-add-order-item" data-add-new="<?php
                    ob_start();
                    ovabrw_wcfm_get_template( 'create-order-field.php' );
                    echo esc_attr( ob_get_clean() );
                ?>">
                    <?php esc_html_e( 'Add Item', 'ova-brw-wcfm' ); ?>
                </button>
            </div>
            <button type="submit" class="button ovabrw-create-order-submit" disabled>
                <?php esc_html_e( 'Create Order', 'ova-brw-wcfm' ); ?>
            </button>
        </div>
        <input type="hidden" name="ovabrw-wcfm-create-order" value="create_order" />
    </form>
</div>