<?php defined( 'ABSPATH' ) || exit;
    // Get product ids by vendor id
    $product_ids    = get_product_ids_by_vendor( get_current_user_id() );
    $order_id       = isset( $_POST['order_id'] ) ? sanitize_text_field( $_POST['order_id'] ) : '';
    $customer_name  = isset( $_POST['name_customer'] ) ? sanitize_text_field( $_POST['name_customer'] ) : '';
    $product_id     = isset( $_POST['product_id'] ) ? sanitize_text_field( $_POST['product_id'] ) : '';
    $order_status   = isset( $_POST['order_status'] ) ? sanitize_text_field( $_POST['order_status'] ) : '';

    // Dates
    $from_date  = isset( $_POST['from_date'] ) ? sanitize_text_field( $_POST['from_date'] ) : '';
    $to_date    = isset( $_POST['to_date'] ) ? sanitize_text_field( $_POST['to_date'] ) : '';

    // Locations
    $location_ids = OVABRW_Get_Data::instance()->get_all_location_ids();
    if ( empty( $location_ids ) || ! is_array( $location_ids ) ) $location_ids = [];

    $pickup_location    = isset( $_POST['pickup_location'] ) ? sanitize_text_field( $_POST['pickup_location'] ) : '';
    $dropoff_location   = isset( $_POST['dropoff_location'] ) ? sanitize_text_field( $_POST['dropoff_location'] ) : '';

    // date & time placeholder
    $datetime_placeholder = ovabrw_get_placeholder_date() . ' ' . ovabrw_get_placeholder_time();

    // Get first day in week
    $first_day = get_option( 'ova_brw_calendar_first_day', '0' );

    if ( empty( $first_day ) ) {
        $first_day = 0;
    }

    // action
    $action = OVABRW_WCFM_Menus::instance()->ovabrw_get_wcfm_menus_url( 'wcfm-manage-order' );
?>
<div class="ovabrw-wcfm-filter">
    <form id="filter-form" action="<?php echo esc_url( $action ); ?>">
        <div class="field-wrap">
            <div class="form-field">
                <label for="order-id"><?php _e( 'Order ID', 'ova-brw-wcfm' ); ?></label>
                <input
                    type="number"
                    name="order_id"
                    id="order-id"
                    value="<?php echo esc_attr( $order_id ); ?>"
                    placeholder="<?php _e( 'number', 'ova-brw-wcfm' ); ?>"
                    min="1"
                />
            </div>
            <div class="form-field">
                <label for="customer-name"><?php _e( 'Customer Name', 'ova-brw-wcfm' ); ?></label>
                <input
                    type="text"
                    name="customer_name"
                    id="customer-name"
                    value="<?php echo esc_attr( $customer_name ); ?>"
                    placeholder="<?php _e( 'name', 'ova-brw-wcfm' ); ?>"
                    autocomplete="off"
                />
            </div>
            <div class="form-field">
                <label for="form-date"><?php _e( 'From Date', 'ova-brw-wcfm' ); ?></label>
                <input
                    type="text"
                    name="from_date"
                    id="from-date"
                    class="ovabrw-wfcm-datetimepicker"
                    value="<?php echo esc_attr( $from_date ); ?>"
                    placeholder="<?php echo esc_attr( $datetime_placeholder ); ?>"
                    data-firstday="<?php echo esc_attr( $first_day ); ?>"
                    autocomplete="off"
                />
            </div>
            <div class="form-field">
                <label for="to-date"><?php _e( 'To Date', 'ova-brw-wcfm' ); ?></label>
                <input
                    type="text"
                    name="to_date"
                    id="to-date"
                    class="ovabrw-wfcm-datetimepicker"
                    value="<?php echo esc_attr( $from_date ); ?>"
                    placeholder="<?php echo esc_attr( $datetime_placeholder ); ?>"
                    data-firstday="<?php echo esc_attr( $first_day ); ?>"
                    autocomplete="off"
                />
            </div>
            <div class="form-field">
                <label for="pickup-location"><?php _e( 'Pickup Location', 'ova-brw-wcfm' ); ?></label>
                <select name="pickup_location" id="pickup-location">
                    <option value=""><?php _e( 'Select location', 'ova-brw-wcfm' ); ?></option>
                    <?php foreach( $location_ids as $location_id ): ?>
                        <option value="<?php echo esc_attr( $location_id ); ?>"<?php selected( $location_id, $pickup_location ); ?>>
                            <?php echo esc_html( get_the_title( $location_id ) ); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="form-field">
                <label for="dropoff-location"><?php _e( 'Dropoff Location', 'ova-brw-wcfm' ); ?></label>
                <select name="dropoff_location" id="dropoff-location">
                    <option value=""><?php _e( 'Select location', 'ova-brw-wcfm' ); ?></option>
                    <?php foreach( $location_ids as $location_id ): ?>
                        <option value="<?php echo esc_attr( $location_id ); ?>"<?php selected( $location_id, $dropoff_location ); ?>>
                            <?php echo esc_html( get_the_title( $location_id ) ); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="form-field">
                <label for="product-id"><?php _e( 'Product', 'ova-brw-wcfm' ); ?></label>
                <select name="product_id" id="product-id">
                    <option value=""><?php _e( 'Select product', 'ova-brw-wcfm' ); ?></option>
                    <?php foreach( $product_ids as $prd_id ): ?>
                        <option value="<?php echo esc_attr( $prd_id ); ?>"<?php selected( $prd_id, $product_id ); ?>>
                            <?php echo esc_html( get_the_title( $prd_id ) ); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="form-field">
                <label for="order-status"><?php _e( 'Order Status', 'ova-brw-wcfm' ); ?></label>
                <select name="order_status" id="order-status">
                    <option value=""><?php _e( 'Select status', 'ova-brw-wcfm' ); ?></option>
                    <?php foreach ( wc_get_order_statuses() as $status => $label ): ?>
                        <option value="<?php echo esc_attr( $status ); ?>">
                            <?php echo esc_html( $label ); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>
        <div class="btn-wrap">
            <button type="submit" class="wcfm_submit_button ovabrw-wcfm-btn">
                <?php _e( 'Filter', 'ova-brw-wcfm' ); ?>
            </button>
        </div>
    </form>
</div>