<?php defined( 'ABSPATH' ) || exit;
	$order_ids 		= ovabrw_wcfm_get_order_ids();
	$per_page 		= apply_filters( 'ovabrw_wcfm_order_posts_per_page', 20 );
	$paged 			= apply_filters( 'ovabrw_wcfm_order_paged', 1 );
	$orders 		= false;
	$total_pages 	= 0;

	if ( ! empty( $order_ids ) && is_array( $order_ids ) ) {
		// Get orders
		$args = apply_filters( 'ovabrw_wcfm_order_query', array(
			'posts_per_page' 	=> $per_page,
		    'post__in'			=> $order_ids,
		    'paged'				=> 1,
		    'order' 			=> 'DESC',
		    'orderby' 			=> 'ID'
		));

		$total_pages = apply_filters( 'ovabrw_wcfm_order_total_pages', ceil( count( $order_ids ) / $per_page ) );
		$orders = wc_get_orders( $args );
	}
?>
<div class="ovabrw-wcfm-orders">
	<div class="ovabrw-wcfm-products_processing"><?php _e( 'Processing...', 'ova-brw-wcfm' ); ?></div>
	<table>
		<thead>
			<tr>
				<th>
					<?php _e( 'Order ID', 'ova-brw-wcfm' ); ?>
					<span class="wcfmfa fa-sort-numeric-up ovabrw-wcfm-sort-orderid" data-order="ASC" title="<?php _e( 'Ascending order', 'ova-brw-wcfm' ); ?>"></span>
					<span class="wcfmfa fa-sort-numeric-down ovabrw-wcfm-sort-orderid active" data-order="DESC" title="<?php _e( 'Descending order', 'ova-brw-wcfm' ); ?>"></span>
				</th>
				<th><?php _e( 'Customer Name', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Dates', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Locations', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Deposit Status', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Insurance Status', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Product', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Order Status', 'ova-brw-wcfm' ); ?></th>
			</tr>
		</thead>
		<tbody>
		<?php if ( count( $order_ids ) && ! empty( $orders ) && is_array( $orders ) ):
			foreach ( $orders as $order ):
				// Order ID
				$order_id = $order->get_id();

				// Custom name
				$buyer = '';

				if ( $order->get_billing_first_name() || $order->get_billing_last_name() ) {
					/* translators: 1: first name 2: last name */
					$buyer = trim( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), $order->get_billing_first_name(), $order->get_billing_last_name() ) );
				} elseif ( $order->get_billing_company() ) {
					$buyer = trim( $order->get_billing_company() );
				} elseif ( $order->get_customer_id() ) {
					$user  = get_user_by( 'id', $order->get_customer_id() );
					$buyer = ucwords( $user->display_name );
				}

				foreach ( $order->get_items() as $item_id => $item ):
					$product = $item->get_product();

					if ( ! $product || ! $product->is_type('ovabrw_car_rental') ) {
						continue;
					}

					$product_id = $product->get_id();

					// Dates
					$pickup_date 	= $item->get_meta( 'ovabrw_pickup_date' );
					$pickoff_date 	= $item->get_meta( 'ovabrw_pickoff_date' );

					// Locations
					$pickup_location 	= $item->get_meta( 'ovabrw_pickup_loc' );
					$dropoff_location 	= $item->get_meta( 'ovabrw_pickoff_loc' );

					// Deposit
					$is_deposit = false;

					if ( isset( $item['ovabrw_deposit_amount_product'] ) && isset( $item['ovabrw_remaining_amount_product'] ) ) {
						$is_deposit = true;

						$remaining_amount = (float) $item['ovabrw_remaining_amount_product'];
						$balance_order_id = isset( $item['ovabrw_remaining_balance_order_id'] ) ? (int) $item['ovabrw_remaining_balance_order_id'] : '';
					}

					// Insurance amount
					$insurance_amount = isset( $item['ovabrw_amount_insurance_product'] ) ? (float) $item['ovabrw_amount_insurance_product'] : '';
				?>
				<tr>
					<td>
						<a href="<?php echo get_wcfm_view_order_url( $order_id ); ?>" target="_blank">
							<?php printf( esc_html__( '#%s', 'ova-brw-wcfm' ), $order_id ); ?>
						</a>
					</td>
					<td>
						<?php echo esc_html( $buyer ); ?>
					</td>
					<td>
					<?php
						if ( $pickup_date && $pickoff_date ) {
							printf( __( '%s @ %s', 'ova-brw-wcfm' ), $pickup_date, $pickoff_date );
						} elseif ( $pickup_date && ! $pickoff_date ) {
							echo esc_html( $pickup_date );
						} elseif ( ! $pickup_date && $pickoff_date ) {
							echo esc_html( $pickoff_date );
						}
					?>
					</td>
					<td>
					<?php
						if ( $pickup_location && $dropoff_location ) {
							printf( __( '%s @ %s', 'ova-brw-wcfm' ), $pickup_location, $dropoff_location );
						} elseif ( $pickup_location && ! $dropoff_location ) {
							echo esc_html( $pickup_location );
						} elseif ( ! $pickup_location && $dropoff_location ) {
							echo esc_html( $dropoff_location );
						}
					?>
					</td>
					<td>
					<?php if ( $is_deposit ): ?>
						<?php if ( $remaining_amount == 0 ): ?>
							<span class="ova_amount_status_insurance_column ova_paid">
								<?php _e( 'Full Payment', 'ova-brw-wcfm' ); ?>
							</span>
						<?php else:
							if ( $balance_order_id ): ?>
								<span class="ova_amount_status_insurance_column ova_paid">
									<?php _e( 'Original Payment', 'ova-brw-wcfm' ); ?>
								</span>
							<?php else: ?>
								<span class="ova_amount_status_insurance_column ova_paid">
									<?php _e( 'Partial Payment', 'ova-brw-wcfm' ); ?>
								</span>
							<?php endif; ?>
						<?php endif; ?>
					<?php endif; ?>
					</td>
					<td>
					<?php if ( $insurance_amount ): ?>
						<span class="ova_amount_status_insurance_column ova_pending">
							<?php _e( 'Received', 'ova-brw-wcfm' ); ?>
						</span>
					<?php else:
						if ( (float) get_post_meta( $product_id, 'ovabrw_amount_insurance', true ) ):
					?>
						<span class="ova_amount_status_insurance_column ova_paid">
							<?php _e( 'Paid for Customers', 'ova-brw-wcfm' ); ?>
						</span>
						<?php endif; ?>
					<?php endif; ?>
					</td>
					<td>
						<a href="<?php echo get_wcfm_edit_product_url( $product_id ); ?>" target="_blank">
							<?php echo get_the_title( $product_id ); ?>
						</a>
					</td>
					<td>
						<select name="update_order_status" class="update_order_status" data-order_id="<?php echo esc_attr( $order_id ); ?>" data-error-per-msg="<?php _e( 'You don\'t have permission to update', 'ova-brw-wcfm' ); ?>" data-error-update-msg="<?php _e( 'Error Update', 'ova-brw-wcfm' ); ?>">
						<?php foreach ( wc_get_order_statuses() as $k => $title ): ?>
							<option value="<?php echo esc_attr( $k ); ?>"<?php selected( $k, 'wc-'.$order->get_status() ); ?>>
								<?php echo esc_html( $title ); ?>
							</option>
						<?php endforeach; ?>
						</select>
					</td>
				</tr>
			<?php endforeach;
			endforeach;
		?>
		<?php else: ?>
			<tr>
				<td colspan="8">
					<?php _e( 'No items found!', 'ova-brw-wcfm' ); ?>
				</td>
			</tr>
		<?php endif; ?>
		</tbody>
		<tfoot>
			<tr>
				<th><?php _e( 'Order ID', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Customer Name', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Dates', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Locations', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Deposit Status', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Insurance Status', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Product', 'ova-brw-wcfm' ); ?></th>
				<th><?php _e( 'Order Status', 'ova-brw-wcfm' ); ?></th>
			</tr>
		</tfoot>
	</table>
	<?php echo ovabrw_wcfm_pagination_manage_order( $total_pages, $paged ); ?>
	<input
		type="hidden"
		name="ovabrw-wcfm-order-query"
		value="<?php echo esc_attr( json_encode( $args ) ); ?>"
	/>
</div>